from os.path import abspath, join, split
import pandas as pd


def get_path(f):
    return split(abspath(f))[0]


list = """\
  J.M. Wooldridge (2015) Introductory Econometrics: A Modern Approach,
  Cengage Learning, 6th edition.
  
  401k       401ksubs    admnrev       affairs     airfare
  alcohol    apple       approval      athlet1     athlet2
  attend     audit       barium        beauty      benefits
  beveridge  big9salary  bwght         bwght2      campus
  card       catholic    cement        census2000  ceosal1
  ceosal2    charity     consump       corn        countymurders
  cps78_85   cps91       crime1        crime2      crime3
  crime4     discrim     driving       earns       econmath
  elem94_95  engin       expendshares  ezanders    ezunem
  fair       fertil1     fertil2       fertil3     fish
  fringe     gpa1        gpa2          gpa3        happiness
  hprice1    hprice2     hprice3       hseinv      htv
  infmrt     injury      intdef        intqrt      inven
  jtrain     jtrain2     jtrain3       kielmc      lawsch85
  loanapp    lowbrth     mathpnl       meap00_01   meap01
  meap93     meapsingle  minwage       mlb1        mroz
  murder     nbasal      nyse          okun        openness
  pension    phillips    pntsprd       prison      prminwge
  rdchem     rdtelec     recid         rental      return
  saving     sleep75     slp75_81      smoke       traffic1
  traffic2   twoyear     volat         vote1       vote2
  voucher    wage1       wage2         wagepan     wageprc
  wine"""


def listWoo():
    print(list)


def dataWoo(name, description=False):
    if description == False:
        return pd.read_csv(join(get_path(__file__), "datasets/" + name + ".csv.bz2"), compression="bz2")
    else:
        with open(join(get_path(__file__), 'description/' + name + '.txt'), 'r') as f:
            print(f.read())



"""
Github page: https://github.com/spring-haru/wooldridge
"""

from .load_data import *

__all__ = ['dataWoo', 'listWoo']

__author__ = 'Tetsu Haruyama'
__version__ = '0.2.0'
__copyright__ = 'Copyright (c) 2019 Tetsu Haruyama'
__license__ = 'GPL-3.0'



import glob
import os
import sys
from setuptools import find_packages, setup


additional_files = []
for filename in glob.iglob('./wooldridge/**', recursive=True):
    if '.csv.bz' in filename:
        additional_files.append(filename.replace('./wooldridge/', ''))

for filename in glob.iglob('./wooldridge/**', recursive=True):
    if '.txt' in filename:
        additional_files.append(filename.replace('./wooldridge/', ''))

setup(
    name='wooldridge',
    version='0.2.0',
    author='Tetsu Haruyama',
    author_email='tetsu.yes@gmail.com',
    packages=find_packages(),
    package_dir={'wooldridge': './wooldridge'},
    include_package_data=True,
    package_data={'wooldridge': additional_files},
    url='https://github.com/spring-haru/wooldridge',
    license='LICENSE',
    description='Data sets from Introductory Econometrics: A Modern Approach (6th ed, J.M. Wooldridge)',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    keywords=['data', 'wooldridge', 'econometrics']
)
